# Code of Conduct

We expect everyone participating in the Mantis community to abide by these guidelines. Please be respectful and inclusive.

## Our Pledge

In the interest of fostering an open and welcoming environment, we as contributors and maintainers pledge to making participation in our project and our community a harassment-free experience for everyone.

## Our Standards

- Be kind and courteous.
- Refrain from demeaning, discriminatory, or harassing behavior and speech.
- Respect differing viewpoints and experiences.
- Gracefully accept constructive criticism.

## Enforcement

Instances of unacceptable behavior will be addressed promptly. If you experience or witness any harassment, please report it to the maintainers.

## Reporting

Please report any issues to [your-email@example.com].

This Code of Conduct is adapted from the Contributor Covenant. 